Class: Fastlane::Actions::AppdevopsAction

Inherits:
Action
  • Object
show all
Defined in:
lib/fastlane/plugin/appdevops/actions/appdevops_action.rb

Class Method Summary collapse

Class Method Details

.authorsObject



22
23
24
# File 'lib/fastlane/plugin/appdevops/actions/appdevops_action.rb', line 22

def self.authors
  ["yaochenfeng"]
end

.available_optionsObject



42
43
44
45
46
47
48
49
50
# File 'lib/fastlane/plugin/appdevops/actions/appdevops_action.rb', line 42

def self.available_options
  [
    FastlaneCore::ConfigItem.new(key: :debug,
      description: "开发模式还是appstore模式",
      optional: true,
      default_value: false,
      is_string: false)
  ]
end

.descriptionObject



18
19
20
# File 'lib/fastlane/plugin/appdevops/actions/appdevops_action.rb', line 18

def self.description
  "app自动化"
end

.detailsObject



37
38
39
40
# File 'lib/fastlane/plugin/appdevops/actions/appdevops_action.rb', line 37

def self.details
  # Optional:
  "app自动化处理证书、打包、发布等"
end

.is_supported?(platform) ⇒ Boolean

Returns:

  • (Boolean)


52
53
54
# File 'lib/fastlane/plugin/appdevops/actions/appdevops_action.rb', line 52

def self.is_supported?(platform)
  true
end

.outputObject

If your method provides a return value, you can describe here what it does



29
30
31
32
33
34
35
# File 'lib/fastlane/plugin/appdevops/actions/appdevops_action.rb', line 29

def self.output
  # Define the shared values you are going to provide
  # Example
  [
    ['AUTO_BUILD_DEBUG', 'A description of what this value contains']
  ]
end

.return_valueObject



26
27
28
# File 'lib/fastlane/plugin/appdevops/actions/appdevops_action.rb', line 26

def self.return_value
  # If your method provides a return value, you can describe here what it does
end

.run(params) ⇒ Object



10
11
12
13
14
15
16
# File 'lib/fastlane/plugin/appdevops/actions/appdevops_action.rb', line 10

def self.run(params)
  isDebug = params[:debug]
  UI.message("开始自动打#{isDebug ? "开发" : "appstore"}版本ipa并且上传!")
  Actions.lane_context[SharedValues::AUTO_BUILD_DEBUG] = isDebug
  other_action.ios_auto_build_ipa
  other_action.ios_auto_upload
end